# Pylogger
This library took me a long time to make

### Download the log_installer.py file and run it [Install Instructions](https://github.com/Legohead69420/pylogger/wiki/Instructions)
## Index
* [💪-Support](#-support)
* [📩-How to download it](#-how-to-download-it)
* [🚦-How to start](#-how-to-start)
* [📝-Instructions](https://github.com/Legohead69420/pylogger/wiki/Instructions)
## 📩 How to download it
> [!IMPORTANT]
Download `log_installer.py` and run it(instructions on wiki)
## 🚦-How to start
> [!IMPORTANT]
Run the "py_logger.py" file itself for the instructions

**All functions contain instructions**
To install this library first download the file pylogger.py and put it into the same folder as your projects and in your code do this command(or run the installer and do the inject function(instructions [here](#-instructions-for-install))):
```
from py_logger import *
```
## 💪-Support
If library does not work message support at [pylogge@gmail.com](https://tinyurl.com/mvytfjrj) or join the [Discord](https://discord.gg/ykwwvZD8Uj)
